==> xray_audit-1.5.1.tar.gz: xray_audit/src/Plugin/xray_audit/tasks/QueryGroup/XrayAuditQueryTaskUserPlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\xray_audit\tasks\QueryGroup;

use Drupal\user\Entity\Role;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_user",
 *   label = @Translation("Users and Roles reports"),
 *   description = @Translation("Reports on the users, role and permissions of this site."),
 *   group = "queries_data",
 *   sort = 3,
 *   operations = {
 *      "count_user" = {
 *          "label" = "User count",
 *          "description" = "List user status and their respective counts."
 *       },
 *      "user_less_activity" = {
 *          "label" = "User activity",
 *          "description" = "List user grouped by last access to the site."
 *       },
 *       "description_of_roles" = {
 *          "label" = "Roles",
 *          "description" = "List the site roles."
 *       },
 *      "count_user_per_role" = {
 *          "label" = "User count per roles",
 *          "description" = "List user grouped by role."
 *       },
 *       "permissions_roles" = {
 *          "label" = "Permissions per role",
 *          "description" = "List the permissions of each role."
 *       }
 *    },
 *   dependencies = {"user"}
 * )
 */
class XrayAuditQueryTaskUserPlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'count_user':
        return $this->countUser();

      case 'user_less_activity':
        return $this->userLessActivity();

      case 'count_user_per_role':
        return $this->usersPerRole();

      case 'description_of_roles':
        return $this->rolesDescription();

      case 'permissions_roles':
        return $this->permissionsPerRole();
    }
    return [];
  }

  /**
   * Get data for operation "count_user".
   *
   * @return array
   *   Data.
   */
  protected function countUser() {

    $headerTable = [$this->t('Status'), $this->t('Number of users')];

    $aggregateQuery = $this->entityTypeManager->getStorage('user')->getAggregateQuery();

    $resultTable = $aggregateQuery->accessCheck(FALSE)
      ->aggregate('uid', 'count')
      ->condition('uid', 0, '!=')
      ->groupBy('status')
      ->execute();

    $total = 0;
    foreach ($resultTable as &$row) {
      $row['status'] = $row['status'] == 1 ? $this->t('Active') : $this->t('Blocked');
      $total += $row['uid_count'];
    }

    $resultTable[] = [
      'status' => $this->t('Total'),
      'user_count' => $total,
    ];

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

  /**
   * Activity users.
   *
   * @return array
   *   Data.
   */
  protected function userLessActivity() {
    $headerTable = [$this->t('Last access'), $this->t('Number of users')];
    $userStorage = $this->entityTypeManager->getStorage('user');
    $current_time = time();

    $one_month_seconds = 2592000;

    // Users last access in 6 months.
    $user_count_6_m = $userStorage->getQuery()
      ->accessCheck(FALSE)
      ->condition('status', 1)
      ->condition('access', $current_time - ($one_month_seconds * 6), '>')
      ->count()
      ->execute();

    // Users lasd access 6 to 12 months.
    $user_count_6_12_m = $userStorage->getQuery()
      ->accessCheck(FALSE)
      ->condition('status', 1)
      ->condition('access', $current_time - ($one_month_seconds * 6), '<')
      ->condition('access', $current_time - ($one_month_seconds * 12), '>')
      ->count()
      ->execute();

    // Users access more than 12 months.
    $user_count_more_12_m = $userStorage->getQuery()
      ->accessCheck(FALSE)
      ->condition('status', 1)
      ->condition('access', $current_time - ($one_month_seconds * 12), '<')
      ->count()
      ->execute();

    $resultTable = [
      [$this->t('Last 6 months'), $user_count_6_m],
      [$this->t('Last 6 to 12 months'), $user_count_6_12_m],
      [$this->t('More than 12 months'), $user_count_more_12_m],
    ];

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

  /**
   * Users per role.
   *
   * @return array
   *   Render array.
   */
  public function usersPerRole() {

    $headerTable = [$this->t('Roles'), $this->t('Count')];
    $resultTable = [];

    $query = $this->database->query("select roles_target_id as role, count(1) as count from user__roles group by role");
    $result = $query->fetchAll();

    foreach ($result as $row) {
      $resultTable[] = [$row->role, $row->count];
    }

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

  /**
   * Description roles.
   *
   * @return array
   *   Render array.
   */
  public function rolesDescription() {
    $headerTable = [
      $this->t('Id'),
      $this->t('Label'),
      $this->t('Langcode'),
    ];
    $resultTable = [];
    $roles = Role::loadMultiple();
    foreach ($roles as $role) {
      $resultTable[] = [
        $role->get('id'),
        $role->get('label'),
        $role->get('langcode'),
      ];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

  /**
   * Permissions and roles.
   *
   * @return array
   *   Render array.
   */
  public function permissionsPerRole() {
    $headerTable = [
      $this->t('Role'),
      $this->t('Permissions'),
    ];
    $resultTable = [];
    $roles = Role::loadMultiple();
    foreach ($roles as $role) {
      $resultTable[] = [
        $role->get('label'),
        implode(', ', $role->get('permissions')),
      ];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

}

==> xray_audit-1.5.4.tar.gz: xray_audit/src/Plugin/xray_audit/tasks/QueryGroup/XrayAuditQueryTaskUserPlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\xray_audit\tasks\QueryGroup;

use Drupal\Core\Database\StatementInterface;
use Drupal\user\Entity\Role;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_user",
 *   label = @Translation("Users and Roles reports"),
 *   description = @Translation("Reports on the users, role and permissions of this site."),
 *   group = "queries_data",
 *   sort = 3,
 *   operations = {
 *      "count_user" = {
 *          "label" = "User count",
 *          "description" = "List user status and their respective counts."
 *       },
 *      "user_less_activity" = {
 *          "label" = "User activity",
 *          "description" = "List user grouped by last access to the site."
 *       },
 *       "description_of_roles" = {
 *          "label" = "Roles",
 *          "description" = "List the site roles."
 *       },
 *      "count_user_per_role" = {
 *          "label" = "User count per roles",
 *          "description" = "List user grouped by role."
 *       },
 *       "permissions_roles" = {
 *          "label" = "Permissions per role",
 *          "description" = "List the permissions of each role."
 *       }
 *    },
 *   dependencies = {"user"}
 * )
 */
class XrayAuditQueryTaskUserPlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'count_user':
        return $this->countUser();

      case 'user_less_activity':
        return $this->userLessActivity();

      case 'count_user_per_role':
        return $this->usersPerRole();

      case 'description_of_roles':
        return $this->rolesDescription();

      case 'permissions_roles':
        return $this->permissionsPerRole();
    }
    return [];
  }

  /**
   * Get data for operation "count_user".
   *
   * @return array
   *   Data.
   */
  protected function countUser() {

    $headerTable = [$this->t('Status'), $this->t('Number of users')];

    $aggregateQuery = $this->entityTypeManager->getStorage('user')->getAggregateQuery();

    $resultTable = $aggregateQuery->accessCheck(FALSE)
      ->aggregate('uid', 'count')
      ->condition('uid', 0, '!=')
      ->groupBy('status')
      ->execute();

    $total = 0;

    /** @var mixed[] $row */
    foreach ($resultTable as &$row) {
      $row['status'] = $row['status'] == 1 ? $this->t('Active') : $this->t('Blocked');
      $total += $row['uid_count'];
    }

    $resultTable[] = [
      'status' => $this->t('Total'),
      'user_count' => $total,
    ];

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

  /**
   * Activity users.
   *
   * @return array
   *   Data.
   */
  protected function userLessActivity() {
    $headerTable = [$this->t('Last access'), $this->t('Number of users')];
    $userStorage = $this->entityTypeManager->getStorage('user');
    $current_time = time();

    $one_month_seconds = 2592000;

    // Users last access in 6 months.
    $user_count_6_m = $userStorage->getQuery()
      ->accessCheck(FALSE)
      ->condition('status', 1)
      ->condition('access', $current_time - ($one_month_seconds * 6), '>')
      ->count()
      ->execute();

    // Users last access 6 to 12 months.
    $user_count_6_12_m = $userStorage->getQuery()
      ->accessCheck(FALSE)
      ->condition('status', 1)
      ->condition('access', $current_time - ($one_month_seconds * 6), '<')
      ->condition('access', $current_time - ($one_month_seconds * 12), '>')
      ->count()
      ->execute();

    // Users access more than 12 months.
    $user_count_more_12_m = $userStorage->getQuery()
      ->accessCheck(FALSE)
      ->condition('status', 1)
      ->condition('access', $current_time - ($one_month_seconds * 12), '<')
      ->count()
      ->execute();

    $resultTable = [
      [$this->t('Last 6 months'), $user_count_6_m],
      [$this->t('Last 6 to 12 months'), $user_count_6_12_m],
      [$this->t('More than 12 months'), $user_count_more_12_m],
    ];

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

  /**
   * Users per role.
   *
   * @return mixed[]
   *   Render array.
   */
  public function usersPerRole() {

    $headerTable = [$this->t('Roles'), $this->t('Count')];
    $resultTable = [];

    $query = $this->database->query("select roles_target_id as role, count(1) as count from user__roles group by role");
    if (!$query instanceof StatementInterface) {
      return [];
    }
    $result = $query->fetchAll();

    foreach ($result as $row) {
      $resultTable[] = [$row->role, $row->count];
    }

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

  /**
   * Description roles.
   *
   * @return array
   *   Render array.
   */
  public function rolesDescription() {
    $headerTable = [
      $this->t('Id'),
      $this->t('Label'),
      $this->t('Langcode'),
    ];
    $resultTable = [];
    $roles = Role::loadMultiple();
    foreach ($roles as $role) {
      $resultTable[] = [
        $role->get('id'),
        $role->get('label'),
        $role->get('langcode'),
      ];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

  /**
   * Permissions and roles.
   *
   * @return array
   *   Render array.
   */
  public function permissionsPerRole() {
    $headerTable = [
      $this->t('Role'),
      $this->t('Permissions'),
    ];
    $resultTable = [];
    $roles = Role::loadMultiple();
    foreach ($roles as $role) {
      $resultTable[] = [
        $role->get('label'),
        implode(', ', $role->get('permissions')),
      ];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

}
